==> ui-1.7.5-sources.jar: nanorep/nanowidget/Components/AbstractViews/dislikeDialog/NRCustomDislikeDialog.java <==
package nanorep.nanowidget.Components.AbstractViews.dislikeDialog;

import android.content.Context;
import android.content.DialogInterface;
import android.support.v4.app.DialogFragment;
import android.widget.Button;
import android.widget.EditText;

import nanorep.nanowidget.Components.AbstractViews.ViewIdsFactory;
import nanorep.nanowidget.Components.AbstractViews.ViewIdsFactory.IDsProducer;
import nanorep.nanowidget.interfaces.DislikeDialogListener;

/**
 * Created by obenoved on 12/03/2018.
 */

public abstract class NRCustomDislikeDialog extends DialogFragment
        implements DialogInterface.OnDismissListener {

    public static String TAG = "dislikeDialog";

    protected DislikeConfiguration dislikeConfiguration;
    protected DislikeDialogListener dislikeDialogListener;
    protected EditText feedbackEditText;
    protected int feedbackDialogType;
    protected int dislikeViewId;
    protected Button cancelButton;
    protected Button okButton;
    public IDsProducer idProducer;

    protected void setConfiguration(DislikeConfiguration dislikeConfiguration) {
        this.dislikeConfiguration = dislikeConfiguration;
        this.feedbackDialogType = dislikeConfiguration.getFeedbackDialogType();
        this.dislikeDialogListener = dislikeConfiguration.getDislikeDialogListener();
    }

    protected void setDislikeViewsProducer(ViewIdsFactory.IDsProducer idProducer) {
        this.idProducer = idProducer;
    }
    protected void setDislikeViewId(int layoutId) {this.dislikeViewId = layoutId;}



    protected NRCustomDislikeDialog() {
    }

}

==> ui-1.8.8-sources.jar: nanorep/nanowidget/Components/AbstractViews/dislikeDialog/NRCustomDislikeDialog.java <==
package nanorep.nanowidget.Components.AbstractViews.dislikeDialog;

import android.content.Context;
import android.content.DialogInterface;
import android.support.v4.app.DialogFragment;
import android.widget.Button;
import android.widget.EditText;

import nanorep.nanowidget.Components.AbstractViews.ViewIdsFactory;
import nanorep.nanowidget.Components.AbstractViews.ViewIdsFactory.IDsProducer;
import nanorep.nanowidget.interfaces.DislikeDialogListener;

/**
 * Created by obenoved on 12/03/2018.
 */

public abstract class NRCustomDislikeDialog extends DialogFragment
        implements DialogInterface.OnDismissListener {

    public static String TAG = "dislikeDialog";

    protected DislikeConfiguration dislikeConfiguration;
    protected DislikeDialogListener dislikeDialogListener;
    protected EditText feedbackEditText;
    protected int feedbackDialogType;
    protected int dislikeViewId;
    protected Button cancelButton;
    protected Button okButton;
    protected int dialogGravity = 0;
    public IDsProducer idProducer;

    protected void setConfiguration(DislikeConfiguration dislikeConfiguration) {
        this.dislikeConfiguration = dislikeConfiguration;
        this.feedbackDialogType = dislikeConfiguration.getFeedbackDialogType();
        this.dislikeDialogListener = dislikeConfiguration.getDislikeDialogListener();
    }

    protected void setDislikeViewsProducer(ViewIdsFactory.IDsProducer idProducer) {
        this.idProducer = idProducer;
    }
    protected void setDislikeViewId(int layoutId) {this.dislikeViewId = layoutId;}

    protected NRCustomDislikeDialog() {
    }

    public void setDialogGravity(int dialogGravity) {
        this.dialogGravity = dialogGravity;
    }
}
